@@ -16,31 +16,34 @@
 
 /*----------------------------------------------------------------------*
  * #define ICONWIN
- *	to enable the fancy icons
+ *	to enable fancy (active) icon
  *
  * #define REMINDERS
  *	to enable the appointment reminder functions
  *
+ * #define NO_REMINDER_EXEC
+ *      to disable the execution of a program on an appointment
+ *
  * #define MAIL
  *	to enable xbiff-type mail reminders
  *
  * #define MAIL_BELL
  *	to enable xbiff-type mail reminders with a beep
  *
- * #define MAIL_SPAWN	"xmh\ -font\ fixed\&"
+ * #define MAIL_SPAWN	"xmh\ -font\ 7x14\&"
  *	to define a mail program to run
  *
  * #define MAIL_SPOOL	"/var/spool/mail/"
- *	define the location of the mail spool to use in case
- *	the environment variable $MAIL isn't used.
+ *	to define the mail spool when the $MAIL variable isn't set
  *
  * program size approximately doubles from no options to all options
  *----------------------------------------------------------------------*/
 #define ICONWIN
 #define REMINDERS
+/* #define NO_REMINDER_EXEC */
 #define MAIL
 /* #define MAIL_BELL */
-/* #define MAIL_SPAWN	"xmh\ -font\ fixed\&" */
+/* #define MAIL_SPAWN	"xmh\ -font\ 7x14\&" */
 /* #define MAIL_SPOOL	"/var/spool/mail/" */
 
 /*----------------------------------------------------------------------*
@@ -58,16 +61,16 @@
 #define REMINDERS_TIME	10
 
 /*----------------------------------------------------------------------*
- * #define FONT_NAME	"fixed"
+ * #define FONT_NAME	"7x14"
  * 	to define the font to be used for appointment reminders
  *
- * #define FG_COLOR_NAME	"white"
- * #define BG_COLOR_NAME	"black"
+ * #define FG_COLOR_NAME	"black"
+ * #define BG_COLOR_NAME	"white"
  * 	to define the foreground/background colors to use
  *----------------------------------------------------------------------*/
-#define FONT_NAME	"fixed"
-#define FG_COLOR_NAME	"white"
-#define BG_COLOR_NAME	"black"
+#define FONT_NAME	"7x14"
+#define FG_COLOR_NAME	"black"
+#define BG_COLOR_NAME	"white"
 
 /*----------------------------------------------------------------------*
  * #define DAY_NAMES	"umtwrfs*"
@@ -78,5 +81,20 @@
  *----------------------------------------------------------------------*/
 #define DAY_NAMES	"umtwrfs*"
 
+/*----------------------------------------------------------------------*
+ * #define SUBTICKS
+ *	to show additional minute/second markings
+ *----------------------------------------------------------------------*/
+#define SUBTICKS
+
+/*----------------------------------------------------------------------*
+ * sort out conflicts
+ *----------------------------------------------------------------------*/
+#if defined (MAIL_BELL) || defined (MAIL_SPAWN) || defined (MAIL_SPOOL)
+# ifndef MAIL
+#  define MAIL
+# endif
+#endif
+
 #endif	/* whole file */
 /*----------------------- end-of-file (C header) -----------------------*/
