@@ -20,23 +20,13 @@
 #ifndef _COMMAND_H
 #define _COMMAND_H
 
-#ifndef WITH_7BIT_MODE
-extern unsigned char hibit_mask;
-#endif
-#ifdef REFRESH_RESOURCE
-extern int refresh_period;
-#endif
-#ifdef KEYSYM_RESOURCE
-extern unsigned char * KeySym_map [256];
-#endif
-
 #ifdef __cplusplus
 extern "C" {
 #endif
    extern void	init_command (char *argv[]);
-   extern void	tty_resize (void);
-   extern void	tty_write (unsigned char *str, int count);
-   extern void	tty_printf (unsigned char *fmt, ...);
+   extern void	tt_resize (void);
+   extern void	tt_write (const unsigned char *str, unsigned int count);
+   extern void	tt_printf (const unsigned char *fmt, ...);
    extern void	main_loop (void);
 
    extern FILE * popen_printer (void);
