@@ -7,18 +7,17 @@
  * Modifications by mj olesen <olesen@me.QueensU.CA>
  * and Raul Garcia Garcia <rgg@tid.es>
  *----------------------------------------------------------------------*/
-#include "rxvt.h"
+#include "main.h"
 
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif
-#include <X11/Xlib.h>
 #include <X11/cursorfont.h>
 
-#include "screen.h"
-#include "xsetup.h"
+#include "command.h"		/* for tt_printf() */
 #include "debug.h"
 #include "graphics.h"
+#include "screen.h"
 
 /* commands:
  * 'C' = Clear
@@ -35,9 +34,12 @@
 #endif
 
 /*----------------------------------------------------------------------*
- * extern variables referenced
+ * extern functions referenced
  */
 
+/*----------------------------------------------------------------------*
+ * extern variables referenced
+ */
 /*----------------------------------------------------------------------*
  * extern variables declared here
  */
@@ -58,7 +60,8 @@ typedef struct grcmd_t {
 
 typedef struct grwin_t {
    Window win;
-   int x, y, w, h;
+   int x, y;
+   unsigned int w, h;
    int screen;
    grcmd_t *graphics;
    struct grwin_t *prev, *next;
@@ -66,10 +69,6 @@ typedef struct grwin_t {
 
 static grwin_t *gr_root = NULL;
 
-/*----------------------------------------------------------------------*
- * extern functions referenced
- */
-
 /*----------------------------------------------------------------------*
  * local functions
  */
@@ -78,7 +77,8 @@ static grwin_t *gr_root = NULL;
 static void
 Gr_NewWindow (int nargs, long *args)
 {
-   int x, y, w, h;
+   int x, y;
+   unsigned int w, h;
    Window win;
    grwin_t *grwin;
    Cursor cursor;
@@ -89,21 +89,18 @@ Gr_NewWindow (int nargs, long *args)
 	return;
      }
 
-   x = args [0] * TermWin.width  / GRX_SCALE + MARGIN;
-   y = args [1] * TermWin.height / GRX_SCALE + MARGIN;
+   x = args [0] * TermWin.width  / GRX_SCALE + TermWin_internalBorder;
+   y = args [1] * TermWin.height / GRX_SCALE + TermWin_internalBorder;
    w = args [2] * TermWin.width  / GRX_SCALE;
    h = args [3] * TermWin.height / GRX_SCALE;
 
-   if (w < 0 || h < 0)
-     return;
-
    win = XCreateSimpleWindow (Xdisplay, TermWin.vt,
 			      x, y, w, h,
 			      0,
-			      pixel_colors [COLORFG],
-			      pixel_colors [COLORBG]);
+			      PixColors [fgColor],
+			      PixColors [bgColor]);
 
-   cursor = XCreateFontCursor (Xdisplay, XC_left_ptr);
+   cursor = XCreateFontCursor (Xdisplay, XC_crosshair);
    XDefineCursor (Xdisplay, win, cursor);
    XMapWindow (Xdisplay, win);
    XSelectInput (Xdisplay, win, ExposureMask);
@@ -123,11 +120,11 @@ Gr_NewWindow (int nargs, long *args)
    grwin->graphics = NULL;
    graphics_up++;
 
-   tty_printf ("\033W%ld\n", (long) grwin->win);
+   tt_printf ("\033W%ld\n", (long) grwin->win);
 }
 
 static void
-Gr_ClearWindow (grwin_t *grwin, grcmd_t *data)
+Gr_ClearWindow (grwin_t *grwin)
 {
    grcmd_t *grcom, *next;
 
@@ -162,21 +159,21 @@ Gr_Text (grwin_t *grwin, grcmd_t *data)
    align = data->coords [2];
 
    if (align & RIGHT_TEXT)
-     x -= XTextWidth (Xfont, data->text, data->coords [3]);
+     x -= XTextWidth (TermWin.font, data->text, data->coords [3]);
    else if (align & HCENTER_TEXT)
-     x -= (XTextWidth (Xfont, data->text, data->coords [3]) >> 1);
+     x -= (XTextWidth (TermWin.font, data->text, data->coords [3]) >> 1);
 
    if (align & TOP_TEXT)
-     y += Xfont->ascent;
+     y += TermWin.font->ascent;
    else if (align & BOTTOM_TEXT)
-     y -= Xfont->descent;
+     y -= TermWin.font->descent;
 
    if (align & VCENTER_TEXT)
-     y -= Xfont->descent + ((Xfont->ascent + Xfont->descent) >>1);
+     y -= TermWin.font->descent + ((TermWin.font->ascent + TermWin.font->descent)>>1);
    if (align & VCAPS_CENTER_TEXT)
-     y += (Xfont->ascent >> 1);
+     y += (TermWin.font->ascent >> 1);
 
-   XDrawString (Xdisplay, grwin->win, Xgc,
+   XDrawString (Xdisplay, grwin->win, TermWin.gc,
 		x, y,
 		data->text, data->coords [3]);
 }
@@ -185,23 +182,23 @@ static void
 Gr_Geometry (grwin_t *grwin, grcmd_t *data)
 {
    if (grwin)
-     tty_printf ("\033G%ld %d %d %d %d %d %d %ld %ld %d\n",
-		 (long) grwin->win,
-		 grwin->x, grwin->y, grwin->w, grwin->h,
-		 TermWin.fwidth,
-		 TermWin.fheight,
-		 (long) GRX_SCALE * TermWin.fwidth  / grwin->w,
-		 (long) GRX_SCALE * TermWin.fheight / grwin->h,
-		 Xdepth);
+     tt_printf ("\033G%ld %d %d %u %u %d %d %ld %ld %d\n",
+		(long) grwin->win,
+		grwin->x, grwin->y, grwin->w, grwin->h,
+		TermWin.fwidth,
+		TermWin.fheight,
+		(long) GRX_SCALE * TermWin.fwidth  / grwin->w,
+		(long) GRX_SCALE * TermWin.fheight / grwin->h,
+		Xdepth);
    else				/* rxvt terminal window size */
-     tty_printf ("\033G0 0 0 %d %d %d %d %ld %ld %d\n",
-		 TermWin.width - 2 * MARGIN,
-		 TermWin.height - 2 * MARGIN,
-		 TermWin.fwidth,
-		 TermWin.fheight,
-		 (long) GRX_SCALE * TermWin.fwidth  / (TermWin.width  - 2 * MARGIN),
-		 (long) GRX_SCALE * TermWin.fheight / (TermWin.height - 2 * MARGIN),
-		 Xdepth);
+     tt_printf ("\033G0 0 0 %d %d %d %d %ld %ld %d\n",
+		TermWin.width - 2 * TermWin_internalBorder,
+		TermWin.height - 2 * TermWin_internalBorder,
+		TermWin.fwidth,
+		TermWin.fheight,
+		(long) GRX_SCALE * TermWin.fwidth  / (TermWin.width  - 2 * TermWin_internalBorder),
+		(long) GRX_SCALE * TermWin.fheight / (TermWin.height - 2 * TermWin_internalBorder),
+		Xdepth);
 }
 
 static void
@@ -242,67 +239,67 @@ Gr_Dispatch (grwin_t *grwin, grcmd_t *data)
       XRectangle rect [NGRX_PTS/4];
    } xdata;
 
-   if (data->color != COLORFG)
+   if (data->color != fgColor)
      {
 	XGCValues gcv;
 
-	gcv.foreground = pixel_colors [data->color];
-	XChangeGC (Xdisplay, Xgc, GCForeground, &gcv);
+	gcv.foreground = PixColors [data->color];
+	XChangeGC (Xdisplay, TermWin.gc, GCForeground, &gcv);
      }
-   switch (data->cmd) {
-    case 'L':
-      if (grwin && (data->ncoords > 3))
-	{
-	   for (n = i = 0; i < data->ncoords; i += 2, n++)
-	     {
-		xdata.pt [n].x = data->coords [i]   * grwin->w / GRX_SCALE;
-		xdata.pt [n].y = data->coords [i+1] * grwin->h / GRX_SCALE;
-	     }
-	   XDrawLines (Xdisplay,
-		       grwin->win, Xgc, xdata.pt, n, CoordModeOrigin);
-	}
-      break;
+   if (grwin)
+     switch (data->cmd) {
+      case 'L':
+	if (data->ncoords > 3)
+	  {
+	     for (n = i = 0; i < data->ncoords; i += 2, n++)
+	       {
+		  xdata.pt [n].x = data->coords [i]   * grwin->w / GRX_SCALE;
+		  xdata.pt [n].y = data->coords [i+1] * grwin->h / GRX_SCALE;
+	       }
+	     XDrawLines (Xdisplay,
+			 grwin->win, TermWin.gc, xdata.pt, n, CoordModeOrigin);
+	  }
+	break;
 
-    case 'P':
-      if (grwin && (data->ncoords > 3))
-	{
-	   for (n = i = 0; i < data->ncoords; i += 2, n++)
-	     {
-		xdata.pt [n].x = data->coords [i]   * grwin->w / GRX_SCALE;
-		xdata.pt [n].y = data->coords [i+1] * grwin->h / GRX_SCALE;
-	     }
-	   XDrawPoints (Xdisplay,
-			grwin->win, Xgc, xdata.pt, n, CoordModeOrigin);
-	}
-      break;
+      case 'P':
+	if (data->ncoords > 3)
+	  {
+	     for (n = i = 0; i < data->ncoords; i += 2, n++)
+	       {
+		  xdata.pt [n].x = data->coords [i]   * grwin->w / GRX_SCALE;
+		  xdata.pt [n].y = data->coords [i+1] * grwin->h / GRX_SCALE;
+	       }
+	     XDrawPoints (Xdisplay,
+			  grwin->win, TermWin.gc, xdata.pt, n, CoordModeOrigin);
+	  }
+	break;
 
-    case 'F':
-      if ((data->ncoords > 0) && (grwin))
-	{
-	   for (n = i = 0; i < data->ncoords; i += 4, n++)
-	     {
-		xdata.rect [n].x = data->coords[i]   * grwin->w / GRX_SCALE;
-		xdata.rect [n].y = data->coords[i+1] * grwin->h / GRX_SCALE;
-		xdata.rect [n].width = ((data->coords[i+2]
-					 - data->coords[i]+1) *
-					grwin->w / GRX_SCALE);
-		xdata.rect [n].height = ((data->coords[i+3]
-					  - data->coords[i+1]+1) *
-					 grwin->h / GRX_SCALE);
-	     }
-	   XFillRectangles (Xdisplay, grwin->win, Xgc, xdata.rect, n);
-	}
-      break;
-    case 'T':	Gr_Text (grwin, data);	break;
-    case 'C':	Gr_ClearWindow (grwin, data);	break;
-   }
+      case 'F':
+	if (data->ncoords > 0)
+	  {
+	     for (n = i = 0; i < data->ncoords; i += 4, n++)
+	       {
+		  xdata.rect [n].x = data->coords[i]   * grwin->w / GRX_SCALE;
+		  xdata.rect [n].y = data->coords[i+1] * grwin->h / GRX_SCALE;
+		  xdata.rect [n].width = ((data->coords[i+2]
+					   - data->coords[i]+1) *
+					  grwin->w / GRX_SCALE);
+		  xdata.rect [n].height = ((data->coords[i+3]
+					    - data->coords[i+1]+1) *
+					   grwin->h / GRX_SCALE);
+	       }
+	     XFillRectangles (Xdisplay, grwin->win, TermWin.gc, xdata.rect, n);
+	  }
+	break;
+      case 'T':	Gr_Text (grwin, data);	break;
+      case 'C':	Gr_ClearWindow (grwin);	break;
+     }
 
-   if (data->color != COLORFG)
+   if (data->color != fgColor)
      {
 	XGCValues gcv;
-
-	gcv.foreground = pixel_colors [COLORFG];
-	XChangeGC (Xdisplay, Xgc, GCForeground, &gcv);
+	gcv.foreground = PixColors [fgColor];
+	XChangeGC (Xdisplay, TermWin.gc, GCForeground, &gcv);
      }
 }
 
@@ -337,11 +334,11 @@ Gr_ButtonReport (int but, int x, int y)
 
    x = GRX_SCALE * (x - grwin->x) / grwin->w;
    y = GRX_SCALE * (y - grwin->y) / grwin->h;
-   tty_printf ("\033%c%ld;%d;%d;\n", but, (long) grwin->win, x, y);
+   tt_printf ("\033%c%ld;%d;%d;\n", but, (long) grwin->win, x, y);
 }
 
 void
-Gr_do_graphics (char cmd, int nargs, long *args, unsigned char *text)
+Gr_do_graphics (int cmd, int nargs, long *args, unsigned char *text)
 {
    static Window last_id = None;
    long win_id;
@@ -451,13 +448,13 @@ Gr_scroll (int count)
    for (grwin = gr_root; grwin != NULL; grwin = next)
      {
 	next = grwin->next;
-	grwin->y -= count * TermWin.fheight;
-	if (grwin->y + grwin->h < - TermWin.hist_size * TermWin.fheight)
+	grwin->y -= (count * TermWin.fheight);
+	if ((grwin->y + grwin->h) < - (TermWin.saveLines * TermWin.fheight))
 	  Gr_DestroyWindow (grwin);
 	else
 	  XMoveWindow (Xdisplay, grwin->win,
 		       grwin->x,
-		       grwin->y + TermWin.hist_start * TermWin.fheight);
+		       grwin->y + (TermWin.hist_start * TermWin.fheight));
      }
 }
 
@@ -475,7 +472,7 @@ Gr_ClearScreen (void)
 	       Gr_DestroyWindow (grwin);
 	     else
 	       XResizeWindow (Xdisplay, grwin->win,
-			      grwin->w, - grwin->y);
+			      grwin->w, -grwin->y);
 	  }
      }
 }
@@ -531,7 +528,7 @@ Gr_Resize (int w, int h)
 	     grwin->y += (TermWin.height - h);
 	     XMoveWindow (Xdisplay, grwin->win,
 			  grwin->x,
-			  grwin->y + TermWin.hist_start * TermWin.fheight);
+			  grwin->y + (TermWin.hist_start * TermWin.fheight));
 	  }
 	Gr_Redraw (grwin);
      }
