@@ -1,7 +1,7 @@
 /*
  * File:	grkelot.c
  *
- * Synopsis:	string -> greek ELOT928 or IBM437 string; 
+ * Synopsis:	string -> greek ELOT928 or IBM437 string;
  * 		4-state FSM implementation.
  *
  * System:	Any (ANSI C)
@@ -47,8 +47,10 @@
 #define RXVT		/* define for use by rxvt */
 
 #ifdef RXVT
-#include "rxvt.h"
-#endif
+#include "config.h"
+#include "feature.h"
+#include "grkelot.h"
+#endif	/* RXVT */
 
 #ifdef GREEK_SUPPORT
 #include "grkelot.h"
@@ -94,7 +96,6 @@ typedef struct s_xlat_type {
 	char *acc_uml;
 } XLAT_TYPE;
 
-
 /* --- Local Data ------------ */
 static K_STATE State[MAX_STATES];
 /* Current State */
@@ -122,7 +123,7 @@ static char i437_xlat_acc_xtra[] = "46-46:250";		/* anw teleia */
 static char i437_xlat_uml[] =	"65-122:128,129,150,131,132,148,130,134,136,141,137,138,139,140,142,143,81,144,145,146,135,151,87,149,147,133,91,92,93,94,95,96,152,153,175,155,156,173,154,158,228,165,161,162,163,164,166,167,113,168,169,171,159,224,170,174,232,157";
 static char i437_xlat_umacc[] =	"65-122:128,129,150,131,132,148,130,134,136,141,137,138,139,140,142,143,81,144,145,146,135,151,87,149,147,133,91,92,93,94,95,96,152,153,175,155,156,173,154,158,42,165,161,162,163,164,166,167,113,168,169,171,159,224,170,174,42,157";
 
-/* 
+/*
  * currently ELOT928 and IBM437 are supported; easy to include others
  * (not recommended: stick to just these 2 if not only the ELOT one)
  */
@@ -170,7 +171,7 @@ kstate_end(void)
 
 	for (i = 0; i < pStateNow->num_xlat; i++)
 		free(pStateNow->xlat[i].pval);
-	if (pStateNow->num_xlat > 0) 
+	if (pStateNow->num_xlat > 0)
 		free(pStateNow->xlat);
 }
 
@@ -264,7 +265,7 @@ kstate_add_xlat(char *str)
  	pStateNow->num_xlat++;
 }
 
-/* 
+/*
  * Ascii only for this implementation
  */
 static void
@@ -366,7 +367,7 @@ greek_xlat(char *s, int num_chars)
 	}
 	s[count] = '\0';
 	return(count);
-	
+
 }
 
 #ifdef TEST
