@@ -13,19 +13,6 @@
 #ifndef _SCREEN_H
 #define _SCREEN_H
 
-typedef struct {
-   int width, height;	/* window size [pixels] */
-   int fwidth, fheight;	/* font width and height [pixels] */
-   int ncol, nrow;	/* window size [characters] */
-   int hist_size;	/* # lines to save in scrollback buffer */
-   int hist_start;	/* how far back into the scrollback buffer */
-   int hist_count;	/* how many scrolled lines saved */
-   Window parent;	/* parent/main window */
-   Window vt;		/* vt100 window */
-} TermWin_t;
-extern TermWin_t TermWin;
-#define MARGIN 2		/* gap between the text and window edges */
-
 /* Screen refresh methods */
 #define NO_REFRESH	2	/* Window not visible at all! */
 #define SLOW_REFRESH	1	/* No Bitblt */
@@ -40,11 +27,6 @@ extern TermWin_t TermWin;
 #define R_RELATIVE	2	/* row movement is relative */
 #define RELATIVE (R_RELATIVE|C_RELATIVE)	/* move row/col relative */
 
-/* modes for scr_erase_line() scr_erase_screen() */
-#define DEL_END		0	/* don't change these values */
-#define DEL_START	1
-#define DEL_ENTIRE	2
-
 /* modes for scr_insdel_chars(), scr_insdel_lines() */
 #define INSERT	-1		/* don't change these values */
 #define DELETE	+1
@@ -59,37 +41,40 @@ extern TermWin_t TermWin;
 #define SECONDARY	1
 
 /* rendition style flags */
-#define RS_NONE		(0)	/* Normal */
-#define RS_FONTMASK	(0x03)	/* occupy two bits */
-#define RS_ASCII	(0)	/* ASCII character set */
-#define RS_GRFONT	(0x01)	/* graphics character set */
-#define RS_GBFONT	(0x02)	/* UK character set */
-#define RS_CURSOR	(0x04)	/* cursor location */
-#define RS_SELECTED	(0x08)	/* selected text */
-#define RS_BOLD		(0x10)	/* bold */
-#define RS_ULINE	(0x20)	/* underline */
-#define RS_BLINK	(0x40)	/* blink */
-#define RS_RVID		(0x80)	/* reverse video */
-
-#define RS_FGMASK	0x0000FF00
-#define RS_BGMASK	0x00FF0000
-#define RS_ATTRMASK	0x000000FF
-
+#define RS_None		0		/* Normal */
+#define RS_Cursor	0x01000000u	/* cursor location */
+#define RS_Select	0x02000000u	/* selected text */
+#define RS_RVid		0x04000000u	/* reverse video */
+#define RS_Uline	0x08000000u	/* underline */
+#define RS_acsFont	0x10000000u	/* ACS - graphics character set */
+#define RS_ukFont	0x20000000u	/* UK character set */
+#define RS_fontMask	(RS_acsFont|RS_ukFont)
 #ifdef KANJI
-# define RL_KANJI1	0x02000000	/* kanji 1st byte */
-# define RL_KANJI2	0x06000000	/* kanji 2nd byte */
-# define RL_KANJI0	0x04000000	/* only kanji */
+# define RS_kanji0	0x40000000u	/* only kanji */
+# define RS_kanji1	0x80000000u	/* kanji 1st byte */
+# define RS_kanjiMask	(RS_kanji0|RS_kanji1)	/* kanji 2nd byte */
+#endif
+
+#define RS_fgMask	0x00001F00u	/* 32 colors */
+#define RS_Bold		0x00008000u	/* bold */
+#define RS_bgMask	0x001F0000u	/* 32 colors */
+#define RS_Blink	0x00800000u	/* blink */
+
+#define RS_attrMask	(0xFF000000u|RS_Bold|RS_Blink)
+
+#ifndef NO_BRIGHTCOLOR
+extern unsigned int color_fgbg;
 #endif
 
 /* how to build & extract colors and attributes */
-#define GET_FG_COLOR(r)		((r & RS_FGMASK)>>8)
-#define GET_BG_COLOR(r)		((r & RS_BGMASK)>>16)
-#define GET_ATTR(r)		((r & RS_ATTRMASK))
+#define GET_FGCOLOR(r)	(((r) & RS_fgMask)>>8)
+#define GET_BGCOLOR(r)	(((r) & RS_bgMask)>>16)
+#define GET_ATTR(r)	(((r) & RS_attrMask))
 
-#define SET_FG_COLOR(r,fg)  (((r) & ~RS_FGMASK)  | ((fg)<<8))
-#define SET_BG_COLOR(r,bg)  (((r) & ~RS_BGMASK)  | ((bg)<<16))
-#define SET_RSTYLE(r,fg,bg) (((r) & RS_ATTRMASK) | ((fg)<<8) | ((bg)<<16))
-#define SET_ATTR(r,a)	    (((r) & ~RS_ATTRMASK)| (a))
+#define SET_RSTYLE(r,fg,bg)	(((r) & RS_attrMask) | ((fg)<<8) | ((bg)<<16))
+#define SET_FGCOLOR(r,fg)	(((r) & ~RS_fgMask)  | ((fg)<<8))
+#define SET_BGCOLOR(r,bg)	(((r) & ~RS_bgMask)  | ((bg)<<16))
+#define SET_ATTR(r,a)		(((r) & ~RS_attrMask)| (a))
 
 #ifdef __cplusplus
 extern "C" {
@@ -100,38 +85,30 @@ extern "C" {
    extern void	scr_bell (void);
    extern int	scr_change_screen (int scrn);
    extern void	scr_rendition (int set, int style);
-   extern void	scr_focus (int in_focus);
-   extern void	scr_add_lines (unsigned char *c, int nl_count, int n);
+   extern void	scr_add_lines (const unsigned char *str, int nlines, int cnt);
    extern void	scr_tab (int count);
    extern void	scr_gotorc (int row, int col, int relative);
    extern void	scr_index (int direction);
    extern void	scr_cursor (int mode);
+   extern void	scr_cursor_visible (int mode);
    extern void	scr_erase_line (int mode);
    extern void	scr_erase_screen (int mode);
    extern void	scr_insdel_lines (int count, int insdel);
    extern void	scr_insdel_chars (int count, int insdel);
    extern void	scr_scroll_region (int top, int bot);
-   extern void	scr_move_to (int y);
-   extern void	scr_page (int dirn, int n);
-   extern void	scr_selection_make (Time time);
-   extern void	scr_selection_send (XSelectionRequestEvent *rq);
-   extern void	scr_selection_request (Time time, int x, int y);
-   extern void	scr_paste_primary (Window win, int prop, int Delete);
-   extern void	scr_selection_clear (void);
-   extern void	scr_selection_delete (void);
-   extern void	scr_selection_extend (int hilite, int x, int y);
-   extern void	scr_selection_start (int x, int y);
-   extern void	scr_selection_click (int clicks, int x, int y);
+   extern int	scr_move_to (int y, int len);
+   extern int	scr_page (int dirn, int n);
    extern void	scr_report_position (void);
    extern void	scr_touch (int x, int y, int width, int height);
-   extern void	scr_charset_set (int set, unsigned char a);
    extern void	scr_charset_choose (int set);
+   extern void	scr_charset_set (int set, unsigned int ch);
    extern void	scr_refresh_region (int startr, int endr, int type);
    extern void	scr_refresh (int type);
    extern void	scr_set_tab (int mode);
    extern void	scr_E (void);
-   extern void	scr_fgcolor (int color);
-   extern void	scr_bgcolor (int color);
+   extern void	scr_color (unsigned int color, unsigned int Intensity);
+   extern int	scr_get_fgcolor (void);
+   extern int	scr_get_bgcolor (void);
    extern void	mouse_report (XButtonEvent *ev);
    /* mode selections */
    extern void	scr_autowrap (int mode);
@@ -141,6 +118,15 @@ extern "C" {
 #ifdef PRINTPIPE
    extern void	scr_printscreen (int fullhist);
 #endif
+   extern void	selection_make (Time tm);
+   extern void	selection_send (XSelectionRequestEvent *rq);
+   extern void	selection_paste (Window win, unsigned prop, int Delete);
+   extern void	selection_request (Time tm, int x, int y);
+   extern void	selection_reset (void);
+   extern void	selection_clear (void);
+   extern void	selection_extend (int hilite, int x, int y);
+   extern void	selection_start (int x, int y);
+   extern void	selection_click (int clicks, int x, int y);
 #ifdef KANJI
    extern void	set_kanji_encoding (const char *str);
 #endif
